==> haskell-posix-paths-0.3.0.0-93.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-9TAHhP88aWvHvVHdByLHVM
key:                  posix-paths-0.3.0.0-9TAHhP88aWvHvVHdByLHVM
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  1c298dfe0ebfb6ab0e1eb6f2b7eeb7e1
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-9TAHhP88aWvHvVHdByLHVM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 unix-2.8.4.0
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-posix-paths-0.3.0.0-94-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-LWWbMaOgexTBtaMxAVg60P
key:                  posix-paths-0.3.0.0-LWWbMaOgexTBtaMxAVg60P
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  84dacc25b47b28ec8fe3a4134f351c86
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-LWWbMaOgexTBtaMxAVg60P
depends:
    base-4.18.2.1 bytestring-0.11.5.3 unix-2.8.4.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
